pitchtools.IntervalObject
=========================

.. inheritance-diagram:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.cents

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.interval_class

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.number

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.semitones

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__abs__

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__float__

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__hash__

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__int__

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__repr__

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__str__
